from distutils.core import setup

setup(
    name='stransliterator',
    version='0.0.1',
    packages=['trasnliterator'],
    url='https://github.com/starenkov/transliterator',
    license='MIT License',
    author='Tarenkov Vyacheslav',
    author_email='tvd1604@gmail.com',
    description='Package converts latin text to cyrillic and vice versa from russian, uzbek and kazakh languages'
)
